Documentation
¶
Overview ¶
Not to be confused with Transmission Control Protocol!
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( ListenAddr string // Contains the IP address to listen on. HistoryLength int // Contains the maximum amount of messages that will be stored. DiscordChannel chan []string // Channel through which messages get sent to Discord. TCPChannel chan []string // Channel through which messages get sent to TCP users. )
Functions ¶
func GetMessage ¶
GetMessage looks up the message at the specified index and returns it if it is stored in the LRU cache.
Types ¶
type Message ¶
Message represents a message. A message is made up of a sender (represented by the username) and its content.
Source Files
¶
- server.go
Click to show internal directories.
Click to hide internal directories.